@@ -113,7 +113,7 @@ def snapshot(returns, grayscale=False, figsize=(10, 8),
     axes[1].set_ylabel('Drawdown', fontname=fontname,
                        fontweight='bold', fontsize=12)
     axes[1].set_yticks(_np.arange(-ddmin, 0, step=ddmin_ticks))
-    axes[1].plot(dd, color=colors[2], lw=1 if grayscale else 1, zorder=1)
+    axes[1].plot(dd, color=colors[2], lw=1 if grayscale else lw, zorder=1)
     axes[1].axhline(0, color='silver', lw=1, zorder=0)
     if not grayscale:
         axes[1].fill_between(dd.index, 0, dd, color=colors[2], alpha=.1)
