@@ -45,10 +45,19 @@ def _get_trading_periods(periods_per_year=252):
     return periods_per_year, half_year
 
 
+def _match_dates(returns, benchmark):
+    returns = returns.loc[
+        max(returns.ne(0).idxmax(), benchmark.ne(0).idxmax()):]
+    benchmark = benchmark.loc[
+        max(returns.ne(0).idxmax(), benchmark.ne(0).idxmax()):]
+
+    return returns, benchmark
+
+
 def html(returns, benchmark=None, rf=0., grayscale=False,
          title='Strategy Tearsheet', output=None, compounded=True,
          periods_per_year=252, download_filename='quantstats-tearsheet.html',
-         figfmt='svg', template_path=None):
+         figfmt='svg', template_path=None, match_dates=False):
 
     if output is None and not _utils._in_notebook():
         raise ValueError("`file` must be specified")
@@ -60,7 +69,12 @@ def html(returns, benchmark=None, rf=0., grayscale=False,
         tpl = f.read()
         f.close()
 
+    # prepare timeseries
     returns = _utils._prepare_returns(returns)
+    if benchmark is not None:
+        benchmark = _utils._prepare_benchmark(benchmark, returns.index, rf)
+        if match_dates is True:
+            returns, benchmark = _match_dates(returns, benchmark)
 
     date_range = returns.index.strftime('%e %b, %Y')
     tpl = tpl.replace('{{date_range}}', date_range[0] + ' - ' + date_range[-1])
@@ -71,7 +85,9 @@ def html(returns, benchmark=None, rf=0., grayscale=False,
                    rf=rf, display=False, mode='full',
                    sep=True, internal="True",
                    compounded=compounded,
-                   periods_per_year=periods_per_year)[2:]
+                   periods_per_year=periods_per_year,
+                   prepare_returns=False)[2:]
+
     mtrx.index.name = 'Metric'
     tpl = tpl.replace('{{metrics}}', _html_table(mtrx))
     tpl = tpl.replace('<tr><td></td><td></td><td></td></tr>',
@@ -80,7 +96,9 @@ def html(returns, benchmark=None, rf=0., grayscale=False,
                       '<tr><td colspan="2"><hr></td></tr>')
 
     if benchmark is not None:
-        yoy = _stats.compare(returns, benchmark, "A", compounded=compounded)
+        yoy = _stats.compare(
+            returns, benchmark, "A", compounded=compounded,
+            prepare_returns=False)
         yoy.columns = ['Benchmark', 'Strategy', 'Multiplier', 'Won']
         yoy.index.name = 'Year'
         tpl = tpl.replace('{{eoy_title}}', '<h3>EOY Returns vs Benchmark</h3>')
@@ -235,7 +253,14 @@ def html(returns, benchmark=None, rf=0., grayscale=False,
 
 def full(returns, benchmark=None, rf=0., grayscale=False,
          figsize=(8, 5), display=True, compounded=True,
-         periods_per_year=252):
+         periods_per_year=252, match_dates=False):
+
+    # prepare timeseries
+    returns = _utils._prepare_returns(returns)
+    if benchmark is not None:
+        benchmark = _utils._prepare_benchmark(benchmark, returns.index, rf)
+        if match_dates is True:
+            returns, benchmark = _match_dates(returns, benchmark)
 
     dd = _stats.to_drawdown_series(returns)
     dd_info = _stats.drawdown_details(dd).sort_values(
@@ -250,7 +275,8 @@ def full(returns, benchmark=None, rf=0., grayscale=False,
         iDisplay(metrics(returns=returns, benchmark=benchmark,
                          rf=rf, display=display, mode='full',
                          compounded=compounded,
-                         periods_per_year=periods_per_year))
+                         periods_per_year=periods_per_year,
+                         prepare_returns=False))
         iDisplay(iHTML('<h4>5 Worst Drawdowns</h4>'))
         if dd_info.empty:
             iDisplay(iHTML("<p>(no drawdowns)</p>"))
@@ -263,7 +289,8 @@ def full(returns, benchmark=None, rf=0., grayscale=False,
         metrics(returns=returns, benchmark=benchmark,
                 rf=rf, display=display, mode='full',
                 compounded=compounded,
-                periods_per_year=periods_per_year)
+                periods_per_year=periods_per_year,
+                prepare_returns=False)
         print('\n\n')
         print('[5 Worst Drawdowns]\n')
         if dd_info.empty:
@@ -276,38 +303,49 @@ def full(returns, benchmark=None, rf=0., grayscale=False,
 
     plots(returns=returns, benchmark=benchmark,
           grayscale=grayscale, figsize=figsize, mode='full',
-          periods_per_year=periods_per_year)
+          periods_per_year=periods_per_year, prepare_returns=False)
 
 
 def basic(returns, benchmark=None, rf=0., grayscale=False,
           figsize=(8, 5), display=True, compounded=True,
-          periods_per_year=252):
+          periods_per_year=252, match_dates=False):
+
+    # prepare timeseries
+    returns = _utils._prepare_returns(returns)
+    if benchmark is not None:
+        benchmark = _utils._prepare_benchmark(benchmark, returns.index, rf)
+        if match_dates is True:
+            returns, benchmark = _match_dates(returns, benchmark)
 
     if _utils._in_notebook():
         iDisplay(iHTML('<h4>Performance Metrics</h4>'))
         metrics(returns=returns, benchmark=benchmark,
                 rf=rf, display=display, mode='basic',
                 compounded=compounded,
-                periods_per_year=periods_per_year)
+                periods_per_year=periods_per_year,
+                prepare_returns=False)
         iDisplay(iHTML('<h4>Strategy Visualization</h4>'))
     else:
         print('[Performance Metrics]\n')
         metrics(returns=returns, benchmark=benchmark,
                 rf=rf, display=display, mode='basic',
                 compounded=compounded,
-                periods_per_year=periods_per_year)
+                periods_per_year=periods_per_year,
+                prepare_returns=False)
 
         print('\n\n')
         print('[Strategy Visualization]\nvia Matplotlib')
 
     plots(returns=returns, benchmark=benchmark,
           grayscale=grayscale, figsize=figsize, mode='basic',
-          periods_per_year=periods_per_year)
+          periods_per_year=periods_per_year,
+          prepare_returns=False)
 
 
 def metrics(returns, benchmark=None, rf=0., display=True,
             mode='basic', sep=False, compounded=True,
-            periods_per_year=252, **kwargs):
+            periods_per_year=252, prepare_returns=True,
+            match_dates=False, **kwargs):
 
     win_year, _ = _get_trading_periods(periods_per_year)
 
@@ -315,10 +353,10 @@ def metrics(returns, benchmark=None, rf=0., display=True,
         raise ValueError("`returns` must be a pandas Series, "
                          "but a multi-column DataFrame was passed")
 
-    if benchmark is not None:
-        if isinstance(returns, _pd.DataFrame) and len(returns.columns) > 1:
-            raise ValueError("`benchmark` must be a pandas Series, "
-                             "but a multi-column DataFrame was passed")
+    if benchmark is not None \
+            and isinstance(benchmark, _pd.DataFrame) and len(benchmark.columns) > 1:
+        raise ValueError("`benchmark` must be a pandas Series, "
+                         "but a multi-column DataFrame was passed")
 
     blank = ['']
 
@@ -327,12 +365,18 @@ def metrics(returns, benchmark=None, rf=0., display=True,
             raise ValueError("`returns` needs to be a Pandas Series. DataFrame was passed")
         returns = returns[returns.columns[0]]
 
-    df = _pd.DataFrame({"returns": _utils._prepare_returns(returns)})
+    if prepare_returns:
+        returns = _utils._prepare_returns(returns)
+
+    df = _pd.DataFrame({"returns": returns})
 
     if benchmark is not None:
         blank = ['', '']
-        df["benchmark"] = _utils._prepare_benchmark(
-            benchmark, returns.index, rf)
+        benchmark = _utils._prepare_benchmark(benchmark, returns.index, rf)
+        if match_dates is True:
+            returns, benchmark = _match_dates(returns, benchmark)
+        df["returns"] = returns
+        df["benchmark"] = benchmark
 
     df = df.fillna(0)
 
@@ -489,7 +533,7 @@ def metrics(returns, benchmark=None, rf=0., display=True,
     for ix, row in dd.iterrows():
         metrics[ix] = row
     metrics['Recovery Factor'] = _stats.recovery_factor(df)
-    metrics['Ulcer Index'] = _stats.ulcer_index(df, rf)
+    metrics['Ulcer Index'] = _stats.ulcer_index(df)
     metrics['Serenity Index'] = _stats.serenity_index(df, rf)
 
     # win rate
@@ -557,11 +601,12 @@ def metrics(returns, benchmark=None, rf=0., display=True,
 
 def plots(returns, benchmark=None, grayscale=False,
           figsize=(8, 5), mode='basic', compounded=True,
-          periods_per_year=252):
+          periods_per_year=252, prepare_returns=True, match_dates=False):
 
     win_year, win_half_year = _get_trading_periods(periods_per_year)
 
-    returns = _utils._prepare_returns(returns)
+    if prepare_returns:
+        returns = _utils._prepare_returns(returns)
 
     if mode.lower() != 'full':
         _plots.snapshot(returns, grayscale=grayscale,
@@ -575,6 +620,12 @@ def plots(returns, benchmark=None, grayscale=False,
 
         return
 
+    # prepare timeseries
+    if benchmark is not None:
+        benchmark = _utils._prepare_benchmark(benchmark, returns.index)
+        if match_dates is True:
+            returns, benchmark = _match_dates(returns, benchmark)
+
     _plots.returns(returns, benchmark, grayscale=grayscale,
                    figsize=(figsize[0], figsize[0]*.6),
                    show=True, ylabel=False,
